/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.util;

import com.liferay.object.model.ObjectField;
import com.liferay.object.service.ObjectFieldLocalServiceUtil;

/**
 * @author Guilherme Camacho
 */
public class ObjectFieldUtil {

	public static ObjectField createObjectField(
		boolean indexed, boolean indexedAsKeyword, String indexedLanguageId,
		String label, String name, boolean required, String type) {

		return createObjectField(
			0, null, indexed, indexedAsKeyword, indexedLanguageId, label, name,
			required, type);
	}

	public static ObjectField createObjectField(
		long listTypeDefinitionId, String dbColumnName, boolean indexed,
		boolean indexedAsKeyword, String indexedLanguageId, String label,
		String name, boolean required, String type) {

		ObjectField objectField = ObjectFieldLocalServiceUtil.createObjectField(
			0);

		objectField.setListTypeDefinitionId(listTypeDefinitionId);
		objectField.setDBColumnName(dbColumnName);
		objectField.setIndexed(indexed);
		objectField.setIndexedAsKeyword(indexedAsKeyword);
		objectField.setIndexedLanguageId(indexedLanguageId);
		objectField.setLabelMap(LocalizedMapUtil.getLocalizedMap(label));
		objectField.setName(name);
		objectField.setRequired(required);
		objectField.setType(type);

		return objectField;
	}

	public static ObjectField createObjectField(String name, String type) {
		return createObjectField(name, name, false, type);
	}

	public static ObjectField createObjectField(
		String label, String name, boolean required, String type) {

		return createObjectField(
			0, null, false, false, null, label, name, required, type);
	}

	public static ObjectField createObjectField(
		String label, String name, String type) {

		return createObjectField(label, name, false, type);
	}

}